""" version which can be consumed from within the module """
VERSION_STR = "0.1.73"
DESCRIPTION = "Pyawskit is your AWS Swiss Army Knife"
APP_NAME = "pyawskit"
LOGGER_NAME = "pyawskit"
